@@ -3,6 +3,7 @@ import gazu
 import shutil
 import glob
 import time
+import re
 
 import kabaret.app.resources as resources
 from kabaret import flow
@@ -21,6 +22,7 @@ class Department(baseflow.departments.Department):
     _short_name = flow.Param(None)
     _file_prefix = flow.Computed(cached=True)
     _shot = flow.Parent(2)
+    _sequence = flow.Parent(4)
     
     file_prefix = flow.Param('{dept}').ui(
         hidden=True,
@@ -44,9 +46,16 @@ class Department(baseflow.departments.Department):
             return dict(
                 department=self.name(),
                 dept=self._short_name.get() if self._short_name.get() else self.name(),
-                context=self._shot.__class__.__name__.lower(),
+                context='shot',
             )
 
+    def get_dependency_template(self):
+        casting = self.root().project().kitsu_bindings().get_shot_casting(
+            self._shot.name(),
+            self._sequence.name())
+        
+        return self.name(), self._shot.oid(), casting
+
 
 class AssetStatus(flow.values.ChoiceValue):
 
@@ -259,10 +268,6 @@ class BuildBlenderScene(baseflow.file.GenericRunAction):
     
     def get_run_label(self):
         return 'Build scene'
-    
-    def get_version(self, button):
-        # Make build action behave as base RunAction by default
-        return RunAction.get_version(self, button)
 
     def get_buttons(self):
         # Make build action behave as base RunAction by default
@@ -279,6 +284,9 @@ class BuildBlenderScene(baseflow.file.GenericRunAction):
             "ROOT_PATH": self.root().project().get_root()
         }
     
+    def target_file_extension(self):
+        return 'blend'
+    
     def _ensure_file(self, name, format, to_edit=False, src_path=None, publish_comment=""):
         files = self._department.files
         file_name = "%s_%s" % (name, format)
@@ -311,9 +319,12 @@ class BuildBlenderScene(baseflow.file.GenericRunAction):
 
         folder = files[name]
 
-        if to_edit:
-            revision = folder.create_working_copy()
+        if folder.has_working_copy(from_current_user=True):
+            revision = folder.get_working_copy()
         else:
+            revision = folder.create_working_copy()
+
+        if not to_edit:
             revision = folder.publish(comment=publish_comment)
 
         folder.set_current_user_on_revision(revision.name())
@@ -335,7 +346,7 @@ class BuildBlenderScene(baseflow.file.GenericRunAction):
             "setup": {'operator_command': "bpy.ops.pipeline.scene_builder_setup",
                       'args': "frame_start={frame_start}, frame_end={frame_end}, resolution_x={resolution_x}, resolution_y={resolution_y}, fps={fps}"},
             "setup_anim": {'operator_command': "bpy.ops.pipeline.scene_builder_setup_animation",
-                           'args': 'alembic_filepath="{alembic_filepath}", assets={assets}'},
+                           'args': 'alembic_filepath="{alembic_filepath}", assets={assets}, do_automate={do_automate}'},
 
             "add_asset": {'operator_command': 'bpy.ops.pipeline.scene_builder_import_asset',
                           'args': 'filepath="{filepath}", asset_name="{asset_name}", target_collection="{asset_type}"'},
@@ -503,6 +514,7 @@ class BuildBlockingScene(BuildBlenderScene):
     _department = flow.Parent()
     _shot = flow.Parent(3)
     _sequence = flow.Parent(5)
+    do_automate = flow.SessionParam(True).ui(editor='bool')
     
     def get_run_label(self):
         return 'Build blocking scene'
@@ -513,6 +525,8 @@ class BuildBlockingScene(BuildBlenderScene):
         alembic_path = self._shot_data.get("alembic_path", None)
         assets_data = self._shot_data.get("assets_data", [])
         assets = []
+        do_automate = self.do_automate.get()
+
         for name, path, asset_type, asset_number in assets_data:
             for i in range(asset_number):
                 assets.append({"name": name,
@@ -524,7 +538,7 @@ class BuildBlockingScene(BuildBlenderScene):
         # Build Blender Python expression
         python_expr = "import bpy\n"
         python_expr += self._blender_cmd("setup_anim",
-                                         alembic_filepath=alembic_path, assets=assets)
+                                         alembic_filepath=alembic_path, assets=assets, do_automate=do_automate)
 
         # Update reference files
 
@@ -584,7 +598,7 @@ class BuildBlockingScene(BuildBlenderScene):
             asset_number = dep.asset_number.get()
 
             if asset_type in ["chars", "props"]:
-                self._shot_data["assets_data"].append((dep.name(), path, asset_type + '_', asset_number))
+                self._shot_data["assets_data"].append((dep.name(), path, asset_type + '-new', asset_number))
             elif asset_type == "board":
                 self._shot_data["board_path"] = path
             # Ignore audio files here, as they will be updated from the ones
@@ -715,12 +729,86 @@ class AnimationDepartment(Department):
     create_anim_scene = flow.Child(CreateAnimationScene)
 
 
+class RefreshMap(flow.Action):
+
+    ICON = ('icons.libreflow', 'refresh')
+
+    _map = flow.Parent()
+
+    def needs_dialog(self):
+        return False
+    
+    def run(self, button):
+        self._map.update_dependencies_data()
+        self._map.touch()
+
+
+class OpenHistory(flow.Action):
+
+    ICON = ("icons.gui", "ui-layout")
+
+    _item = flow.Parent()
+
+    def needs_dialog(self):
+        return False
+    
+    def run(self, button):
+        revision_oid = self._item.revision_oid.get()
+        history_oid = self.root().session().cmds.Flow.resolve_path(revision_oid+'/../..')
+        
+        return self.get_result(goto=history_oid)
+
+
+class RenderDependencyItemFile(baseflow.dependency.DependencyItemFile):
+
+    goto_history = flow.Child(OpenHistory).ui(label='Show in history')
+
+
+class RenderDependencyView(baseflow.dependency.DependencyView):
+
+    ICON = ('icons.libreflow', 'dependencies')
+
+    refresh = flow.Child(RefreshMap)
+
+    def get_site_name(self):
+        return None
+    
+    def get_revision_name(self):
+        return None
+    
+    def columns(self):
+        return ['Dependency', 'Last revision']
+    
+    def _get_mapped_item_type(self, mapped_name):
+        if re.match(r'.*_\d\d\d$', mapped_name):
+            return RenderDependencyItemFile
+        else:
+            return super(RenderDependencyView, self)._get_mapped_item_type(mapped_name)
+    
+    def _fill_row_cells(self, row, item):
+        row['Dependency'] = item.dependency_name.get()
+        row['Last revision'] = item.revision.get()
+    
+    def _fill_row_style(self, style, item, row):
+        super(RenderDependencyView, self)._fill_row_style(style, item, row)
+
+        if item.status.get() == 'Available':
+            style['Last revision_foreground-color'] = '#45cc3d'
+        else:
+            style['Last revision_foreground-color'] = '#d5000d'
+        
+        style['icon'] = ('icons.libreflow', 'blank')
+
+
 class BuildRenderScene(BuildBlenderScene):
 
     _department = flow.Parent()
     _shot = flow.Parent(3)
     _sequence = flow.Parent(5)
 
+    dependencies = flow.Child(RenderDependencyView).ui(expanded=True)
+    predictive_only = flow.Param(True).ui(hidden=True)
+
     def extra_argv(self):
         # Get scene builder arguments
         render_path = self._shot_data.get("render_path", None)
@@ -743,6 +831,8 @@ class BuildRenderScene(BuildBlenderScene):
 
         if "animation_blend" in files.mapped_names():
             latest_revision = files["animation_blend"].get_head_revision()
+        elif "Animation_blend" in files.mapped_names():
+            latest_revision = files["Animation_blend"].get_head_revision()
         elif "blocking_blend" in files.mapped_names():
             latest_revision = files["blocking_blend"].get_head_revision()
         elif "breakdown_blend" in files.mapped_names():
@@ -804,12 +894,11 @@ class BuildRenderScene(BuildBlenderScene):
         # Configure render dir
         self._ensure_folder(
             name='passes',
-            to_edit=True,
         )
 
         self._department.files.touch()
 
-        # Store anim and alembic output path
+        # Store anim and jsx output path
         self._shot_data["render_path"] = render_path.replace("\\", "/")
         self._shot_data["jsx_path"] = jsx_path.replace("\\", "/")
 
@@ -940,9 +1029,9 @@ class RenderSequencePlayblasts(flow.Action):
             
             revision_name = rev.name()
 
-        file.render_playblast.revision_name.set(revision_name)
-        file.render_playblast.use_simplify.set(use_simplify)
-        file.render_playblast.run('Add to render pool')
+        file.render_blender_playblast.revision_name.set(revision_name)
+        file.render_blender_playblast.use_simplify.set(use_simplify)
+        file.render_blender_playblast.run('Add to render pool')
     
     def run(self, button):
         for shot in self.shots.mapped_items():
