@@ -35,22 +35,30 @@ class Department(baseflow.departments.Department):
             return dict(
                 department=self.name(),
                 dept=self._short_name.get() if self._short_name.get() else self.name(),
-                context=self._parent.__class__.__name__.lower(),
+                context='asset',
             )
 
+
 class DesignDepartment(Department):
     _short_name = flow.Param("dsn")
 
+
 class ModelingDepartment(Department):
     _short_name = flow.Param("mod")
 
+
 class ShadingDepartment(Department):
     _short_name = flow.Param("sha")
 
+
 class RiggingDepartment(Department):
     _short_name = flow.Param("rig")
 
 
+class CompDepartment(Department):
+    _short_name = flow.Param("comp")
+
+
 class Util(flow.Object):
 
     _util_map = flow.Parent()
@@ -141,6 +149,7 @@ class AssetDepartments(flow.Object):
     modeling = flow.Child(ModelingDepartment)
     rigging = flow.Child(RiggingDepartment)
     shading = flow.Child(ShadingDepartment)
+    compositing = flow.Child(CompDepartment)
 
 
 class RevisionType(flow.values.ChoiceValue):
@@ -370,11 +379,16 @@ class AssetFiles(flow.DynamicMap):
                 "dsn": ["design.ai", "layers", "layers_add"],
             }
         else:
-            return {
-                "mod": ["modelisation_export.fbx"],
+            files = {
+                "mod": ["modelisation_export.fbx", "modelisation_export.obj", "modelisation.blend"],
                 "rig": ["rig.blend", "rig_ok.blend"],
                 "sha": ["textures"],
             }
+            
+            if asset_type == 'props':
+                files['dsn'] = ['design.ai']
+            
+            return files
     
     def file_data(self, mapped_name):
         return self._files_data[mapped_name]
@@ -426,11 +440,26 @@ class ConfigureAssetAction(flow.Action):
         return self.get_result(goto=self._asset.oid())
 
 
+class GotoAsset(flow.Action):
+
+    _asset = flow.Parent()
+
+    def needs_dialog(self):
+        return False
+    
+    def allow_context(self, context):
+        return False
+    
+    def run(self, button):
+        return self.get_result(goto=self._asset.oid())
+
+
 class Asset(baseflow.lib.Asset):
     _asset_family = flow.Parent(2)
     _asset_type = flow.Parent(4)
     departments = flow.Child(AssetDepartments).ui(expanded=True)
     configure_action = flow.Child(ConfigureAssetAction)
+    goto_action = flow.Child(GotoAsset)
     file_prefix = flow.Param('{asset_name}').ui(
         hidden=True,
         editable=False,
@@ -633,12 +662,92 @@ class CreateAssetAction(flow.Action):
         return self.get_result(next_action=asset.configure_action.oid())
 
 
+class RefreshAssets(flow.Action):
+
+    ICON = ('icons.libreflow', 'refresh')
+
+    _asset_browser = flow.Parent()
+
+    def needs_dialog(self):
+        return False
+    
+    def run(self, button):
+        self._asset_browser.refresh_assets()
+        self._asset_browser.touch()
+
+
+class AssetBrowser(flow.DynamicMap):
+
+    _asset_lib = flow.Parent()
+    _asset_data = flow.Param({}).ui(editor='textarea')
+    refresh = flow.Child(RefreshAssets).ui(label='Refresh list')
+
+    def __init__(self, parent, name):
+        super(AssetBrowser, self).__init__(parent, name)
+        self._cache_names = None
+        self._cache_data = None
+
+    def mapped_names(self, page_num=0, page_size=None):
+        names, _ = self._ensure_asset_data()
+        return names
+    
+    def refresh_assets(self):
+        self._cache_names = None
+        self._cache_data = None
+        data = {}
+
+        for at in self._asset_lib.asset_types.mapped_items():
+            for af in at.asset_families.mapped_items():
+                mapped_names = af.assets.mapped_names()
+                data.update(dict.fromkeys(mapped_names, (at.name(), af.name())))
+
+        self._asset_data.set(data)
+    
+    def _ensure_asset_data(self):
+        if self._cache_names is None:
+            self._cache_data = self._asset_data.get()
+            self._cache_names = sorted(self._cache_data.keys())
+        
+        return self._cache_names, self._cache_data
+    
+    def _get_asset_data(self, name):
+        _, data = self._ensure_asset_data()
+        return data[name]
+
+    def columns(self):
+        return ['Name', 'Type', 'Family']
+    
+    def rows(self):
+        # Manually fill rows to avoid a huge number of calls to get_mapped
+        rows = []
+        asset_names, asset_data = self._ensure_asset_data()
+        project_name = self.root().project().name()
+        oid_format = '/{project}/asset_lib/asset_types/{type}/asset_families/{family}/assets/{asset}'
+
+        for name in asset_names:
+            data = asset_data[name]
+            oid = oid_format.format(project=project_name, type=data[0], family=data[1], asset=name)
+            style = {
+                'activate_oid': oid + '/goto_action'
+            }
+            rows.append((oid, {
+                'Name': name,
+                'Type': data[0],
+                'Family': data[1],
+                '_style': style,
+            }))
+        
+        return rows
+
+
 class AssetLib(flow.Object):
 
     asset_types = flow.Child(AssetTypes).ui(
         expanded=True,
-        show_filter=True,
-    )
+        default_height=150)
+    browse_assets = flow.Child(AssetBrowser).ui(
+        expanded=True,
+        show_filter=True)
     add_asset = flow.Child(CreateAssetAction).ui(
         label="Add asset"
     )
