@@ -11,7 +11,7 @@ from qtpy import QtWidgets, QtGui, QtCore
 from kabaret.subprocess_manager import SubprocessManager
 
 from .session import BaseGUISession, DebugGUISession
-from libreflow.resources.icons import libreflow
+from libreflow.resources.icons import libreflow, status
 from libreflow.resources import file_templates
 import libreflow.utils.kabaret as kutils
 
@@ -29,11 +29,21 @@ if CUSTOM_HOME:
     from .thesiren_custom_home import MyHomeRoot
 DEBUG = False
 SCRIPT_VIEW = True
+JOBS_VIEW = True
+
 try:
     from kabaret.script_view import script_view
 except ImportError:
     SCRIPT_VIEW = False
 
+try:
+    from libreflow.utils.kabaret.jobs.jobs_view import JobsView
+    from libreflow.utils.kabaret.jobs.jobs_actor import Jobs
+except ImportError:
+    print("ERROR: kabaret.jobs not found")
+    JOBS_VIEW = False
+
+
 class MyStudioGUISession(gui.KabaretStandaloneGUISession):
     def register_view_types(self):
         super(MyStudioGUISession, self).register_view_types()
@@ -51,6 +61,14 @@ class MyStudioGUISession(gui.KabaretStandaloneGUISession):
                 area=QtCore.Qt.RightDockWidgetArea,
             )
 
+        if JOBS_VIEW:
+            type_name = self.register_view_type(JobsView)
+            self.add_view(
+                type_name,
+                hidden=not DEBUG,
+                area=QtCore.Qt.RightDockWidgetArea,
+            )
+
     def _create_actors(self):
         """
         Instanciate the session actors.
@@ -63,6 +81,8 @@ class MyStudioGUISession(gui.KabaretStandaloneGUISession):
             return super(MyStudioGUISession, self)._create_actors()
         subprocess_manager = kutils.subprocess_manager.SubprocessManager(self)
 
+        jobs = Jobs(self)
+
 
 def process_remaining_args(args):
     parser = argparse.ArgumentParser(
@@ -74,12 +94,19 @@ def process_remaining_args(args):
     parser.add_argument(
         '-s', '--site', default='LFS', dest='site'
     )
+    parser.add_argument(
+        '-j', '--jobs_default_filter', dest='jobs_default_filter'
+    )
     values, _ = parser.parse_known_args(args)
 
     if values.site:
         os.environ["KABARET_SITE_NAME"] = values.site
     if values.user:
         os.environ["USER_NAME"] = values.user
+    if values.jobs_default_filter:
+        os.environ["JOBS_DEFAULT_FILTER"] = values.jobs_default_filter
+    else:
+        os.environ["JOBS_DEFAULT_FILTER"] = values.site
 
 
 def main(argv):
